@@ -20,20 +20,24 @@
 #' data("mlmm.gwas.AD")
 #' results <- run_entire_gwas_pipeline(floweringDateAD, list(Xa), list(K.add))
 #' @export
-run_entire_gwas_pipeline = function(Y, XX, KK, nbchunks=2, maxsteps=20, cofs=NULL, female=NULL, male=NULL){
+run_entire_gwas_pipeline = function(Y, XX, KK, nbchunks=2, maxsteps=20, cofs=NULL, female=NULL, male=NULL, threshold=NULL){
     res = list()
 
     res$pval = mlmm_allmodels(Y, XX, KK, nbchunks, maxsteps, cofs, female, male)
     sel.XX = frommlmm_toebic(XX, res$pval)
     nb.snp = ncol(XX[[1]])
     res$eBic = eBIC_allmodels(Y, sel.XX, KK, nb.snp, cofs, female, male)
+    res$threshold = threshold_allmodels(threshold=threshold, res_mlmm=res$pval)
 
-    if(which.min(res$eBic[, grep("eBIC_", colnames(res$eBic))[1]]) == 1){#nb. the name of the column of the eBIC is variable, ie. eBIC_[lambda]
+    if(which.min(res$eBic[, grep("eBIC_", colnames(res$eBic))[1]]) == 1 & length(res$threshold)==1){#nb. the name of the column of the eBIC is variable, ie. eBIC_[lambda]
         warning("The model with the lowest eBic is the null model (without markers used as fixed effects).")
     }else{
-        sel.XXclass = fromeBICtoEstimation(sel.XX, res$eBic)
+        sel.XXclass = fromeBICtoEstimation(sel.XX, res$eBic,res$threshold)
         res$effects = Estimation_allmodels(Y, sel.XXclass, KK, cofs, female, male)
     }
-
     res
-}
\ No newline at end of file
+}
+
+
+# selec_XX = sel.XX
+# nb.snp=500
\ No newline at end of file
